Skip to contents

This function retrieves a list of all available tables (resources) in the RIO package.

Usage

rio_list_tables()

Value

A tibble with information about each table, including ID, name, and description.

Examples

if (FALSE) { # \dontrun{
tables <- rio_list_tables()
} # }