Skip to contents

This function creates a timeline plot showing the validity periods of institutions or other entities.

Usage

rio_visualize_timeline(
  data,
  id_col,
  name_col = NULL,
  start_date_col = "BEGINDATUM",
  end_date_col = "EINDDATUM"
)

Arguments

data

A tibble containing data with start and end dates.

id_col

The name of the column containing entity IDs.

name_col

The name of the column containing entity names. Default is NULL.

start_date_col

The name of the column containing start dates. Default is "BEGINDATUM".

end_date_col

The name of the column containing end dates. Default is "EINDDATUM".

Value

A ggplot object showing the timeline.

Examples

if (FALSE) { # \dontrun{
institutions <- rio_get_data(dataset_id = "institution-resource-id")
plot <- rio_timeline(
  institutions,
  id_col = "INSTELLINGSCODE",
  name_col = "INSTELLINGSNAAM"
)
} # }